pub struct FMDemodulator { /* private fields */ }Expand description
FM Demodulator (Timing)
Based on John Ehlers’ “A Technical Description of Market Data for Traders”. It extracts market timing information by demodulating the frequency-modulated price spectrum using a hard limiter and a SuperSmoother filter.
Implementations