pub struct CenterOfGravity { /* private fields */ }Expand description
Center of Gravity (CG) Oscillator
Based on John Ehlers’ “The CG Oscillator”. The CG Oscillator is a smoothed oscillator with essentially zero lag. It identifies turning points by calculating the balance point of prices over a window.
Implementations