pub struct ChannelCycle { /* private fields */ }Expand description
Channel Cycle Indicator
Based on John Ehlers’ “Inferring Trading Strategies from Probability Distribution Functions”. Detrends price using a channel normalization, then applies a bandpass filter to extract a near sine wave, and computes a leading cosine-like function.
Implementations