pub struct ChoppinessIndex { /* private fields */ }Expand description
Choppiness Index
The Choppiness Index is a volatility indicator used to determine if the market is trending or ranging (choppy). Values above 61.8 indicate choppiness, while values below 38.2 indicate trending.
Implementations