pub struct CyberCycle { /* private fields */ }Expand description
John Ehlers’ Cyber Cycle As described in “Cybernetic Analysis for Stocks and Futures” (2004), Chapter 4, Page 33-34.
The Cyber Cycle is an indicator that models the cyclical component of price movement. It uses a 4-bar symmetrical finite impulse response (FIR) filter for smoothing and an alpha calculation to isolate the cycle.
Implementations