DSMA

Struct DSMA 

pub struct DSMA { /* private fields */ }
Deviation Scaled Moving Average (DSMA)

Based on John Ehlers’ “Deviation Scaled Moving Average” (2018). DSMA is an adaptive moving average that modifies the alpha term of an EMA based on the amplitude of an oscillator scaled in Standard Deviations from the mean. This allows it to adapt rapidly to price variations while maintaining heavy smoothing when variations are small.

Implementations

Source

impl DSMA

pub fn new(period: usize) -> Self