pub struct EhlersStochastic { /* private fields */ }Expand description
Ehlers Stochastic (MESA Stochastic)
Based on John Ehlers’ “Anticipating Turning Points”. It is a standard Stochastic calculation applied to the output of a Roofing Filter. This removes the distortion caused by Spectral Dilation in standard Stochastics.
Implementations