pub struct InverseFisherTransform;Expand description
Inverse Fisher Transform (IFT)
Based on John Ehlers’ “The Inverse Fisher Transform”. The Inverse Fisher Transform is a compressive transform that alters the Probability Distribution Function (PDF) of an oscillator to produce clear black-or-white signals.
It is mathematically equivalent to the Hyperbolic Tangent (tanh) function.
Implementations