pub struct Kama { /* private fields */ }Expand description
Kaufman’s Adaptive Moving Average (KAMA)
KAMA is an adaptive moving average that adjusts its smoothing based on the efficiency of price movement (signal-to-noise ratio).
Implementations