MAMA

Struct MAMA 

pub struct MAMA { /* private fields */ }
MESA Adaptive Moving Average (MAMA) Adapts to price movement based on the rate change of phase as measured by the Hilbert Transform Discriminator. Returns (MAMA, FAMA).

Implementations

Source

impl MAMA

pub fn new(fast_limit: f64, slow_limit: f64) -> Self