pub struct ProjectedMovingAverage { /* private fields */ }Expand description
Projected Moving Average (PMA)
Based on John Ehlers’ “Removing Moving Average Lag” (TASC March 2025). Adds the linear regression slope multiplied by half the length to a simple moving average to compensate for the lag inherent in moving averages. Returns (PMA, Predict).
Implementations