pub struct ReverseEMA { /* private fields */ }Expand description
Reverse EMA
Based on John Ehlers’ article “The Reverse EMA Indicator” (TASC September 2017). This indicator provides a causal forward and backward EMA that minimizes lag. It uses a series of filters to align the EMA and reduce aliasing.
By varying the alpha parameter, it can display trend or cycle information with very low lag. Typical values: Trend = 0.05, Cycle = 0.3.
Implementations