pub struct ReversionIndex { /* private fields */ }Expand description
The Reversion Index
Based on John Ehlers’ “The Reversion Index” (TASC January 2026). This indicator identifies peaks and valleys in ranging markets by summing bar-to-bar price changes and normalizing them by their absolute values. It uses two SuperSmoother filters (Length 4 and 8) as trigger and signal lines.
Implementations