pub struct RobustnessEvaluator { /* private fields */ }Expand description
Robustness Score
Based on John Ehlers’ “A Procedure to Evaluate Trading Strategy Robustness”. Robustness is determined by the slope of the net profit as a function of the number of tests run. Score = (NetProfit at midpoint of ranked tests) / (Maximum NetProfit). A score >= 0.75 (75%) indicates a reasonable expectation that out-of-sample performance will be at least 75% of optimized in-sample net profit.
Implementations
Sourceimpl RobustnessEvaluator
impl RobustnessEvaluator
pub fn new() -> Self
pub fn add_test_result(&mut self, net_profit: f64)
pub fn calculate_score(&self) -> f64