pub struct SDO { /* private fields */ }Expand description
Stochastic Distance Oscillator (SDO)
Based on Vitali Apirine’s article “The Stochastic Distance Oscillator” (TASC June 2023). The SDO is a momentum study that shows the magnitude of the current distance relative to the maximum-minimum distance range over a set period.
Implementations