pub struct TruncatedBandpass { /* private fields */ }Expand description
Truncated Bandpass Filter
Based on John Ehlers’ “Truncated Indicators” (TASC July 2020). It applies a Bandpass filter but truncates the feedback loop at a specific length to prevent “ringing” and better handle sharp price movements.
Implementations