Module hsmm

Module hsmm 

Hidden Semi-Markov Models (HSMM)

Source: Yu (2010) “Hidden Semi-Markov Models”

HSMMs extend HMMs by allowing explicit modeling of the duration of each state, avoiding the geometric duration distribution inherent in standard HMMs.

Structs

HSMM
A Hidden Semi-Markov Model.

Enums

DurationDistribution
A distribution for the duration of a hidden state.