SmoothingAlgorithm

Trait SmoothingAlgorithm 

pub trait SmoothingAlgorithm:
    Next<f64, Output = f64>
    + Clone
    + Send
    + Sync { }
A trait for algorithms that smooth a series of values (e.g., SMA, EMA). This allows indicators like SuperTrend or Keltner Channels to be generic over their MA type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> SmoothingAlgorithm for T
where T: Next<f64, Output = f64> + Clone + Send + Sync,

Blanket implementation for types that satisfy the SmoothingAlgorithm requirements.