pub trait AsFeatures {
// Required method
fn as_features(&self) -> &[f64];
}Expand description
Common trait for feature extractors that want to expose a stable “feature vector” view. (Future expansion point for a unified FeatureVector trait.)
Required Methods
Sourcefn as_features(&self) -> &[f64]
fn as_features(&self) -> &[f64]
Returns a slice of the current feature values (for quick ML consumption).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".