pub struct FisherTransform;Expand description
Fisher Transform
Based on John Ehlers’ “Using The Fisher Transform”. The Fisher Transform changes the Probability Density Function (PDF) of any waveform so that the transformed output has an approximately Gaussian PDF. This accentuates the largest deviations from the mean, providing sharp and easy to identify turning points.
Implementations