pub struct FRAMA { /* private fields */ }Expand description
Fractal Adaptive Moving Average (FRAMA) As described by John Ehlers.
The FRAMA uses the fractal dimension of prices to dynamically adapt its smoothing constant (alpha). It rapidly follows major changes in price and slows down when prices are in congestion.
The length parameter specifies the period N. If an odd length is provided,
it will be automatically converted to an even number (by adding 1) because the
fractal dimension calculation requires splitting the period into two equal halves.
Implementations