pub struct MAMA { /* private fields */ }Expand description
MESA Adaptive Moving Average (MAMA) Adapts to price movement based on the rate change of phase as measured by the Hilbert Transform Discriminator. Returns (MAMA, FAMA).
Implementations