pub struct MESAStochastic { /* private fields */ }Expand description
MESA Stochastic
Based on John Ehlers’ “Predictive and Successful Indicators” (2014) and “Anticipating Turning Points”. It applies a standard Stochastic formula to price data preprocessed by a Roofing Filter, followed by a SuperSmoother filter.
Implementations