Indicator metadata definition.
IMPORTANT PROCESS RULE (see AGENTS.md + task quantwave-i9dn):
When adding a new indicator or making significant changes to an existing one,
you MUST also create/update its corresponding XXX_METADATA constant in the
same session, before landing the plane / doing the final git push.
This metadata is the single source of truth used by:
- Documentation generation (mkdocs)
- Python package DX features
Python metadata is codegen’d from this registry (quantwave-iqq7): python scripts/regenerate_metadata_registry.py python scripts/generate_indicator_metadata.py