pub struct UltimateSmoother { /* private fields */ }Expand description
UltimateSmoother Filter
Based on John Ehlers’ “The Ultimate Smoother” It conceptually has zero lag in the Pass Band and has minimum lag in the transition band. It is constructed by subtracting the High Pass response from the input data (cancellation).
Implementations