Module chain_analytics

Module chain_analytics 

Structs

OIZones
OI concentration zones (Support and Resistance).

Functions

atm_straddle
ATM Straddle analytics. Returns (atm_strike, straddle_premium, implied_move_pct).
chain_pcr
Chain-level Put-Call Ratio (PCR). Returns total PE_OI / total CE_OI.
gex_flip_strike
GEX Flip Strike. Returns the strike price where the cumulative Net GEX changes sign.
gex_per_strike
Gamma Exposure (GEX) per strike. Returns a Vec of (ce_gex, pe_gex, net_gex) per strike. CE GEX = OI * Gamma * Spot * LotSize * 0.01 PE GEX = OI * Gamma * Spot * LotSize * -0.01
max_pain
Max Pain strike calculation. Returns the strike price where the total loss to option buyers is minimized.
oi_zones
strike_pcr
Per-strike Put-Call Ratio (PCR). Returns Vec of PE_OI / CE_OI for each strike.
synthetic_futures
Synthetic Futures calculation per strike. Future Price = CE_LTP - PE_LTP + Strike