pub trait IndicatorConfig { type Indicator: Next<f64>; // Required method fn build(&self) -> Self::Indicator; }
A trait for indicator configurations that can build their respective streaming state machines.
Build a new instance of the indicator state machine.